##  Capturing Versions
For most use cases, maintaining version details does not provide significant value. However, if versioning is relevant for you for purposes such as testing, training, or rollout, you can capture it in the Release field of the application fact sheets within the Name & Description subsection. Information in the Release field is suffixed with the fact sheet name to form the <full name> and <display name>, distinguishing different versions of the application in reports and diagrams. To learn about fact sheet naming convention, see [Fact Sheet Naming Convention](https://help.sap.com/docs/leanix/ea/creating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759925e7a441014a7e9e6f502b4cd21__fact_sheet_naming_convention).
In SaaS products, when versions are continuously updated, and all users run the latest version, version numbers are generally irrelevant, and we don’t recommend tracking them on application fact sheets.
